@@ -1,12 +1,12 @@
 #!/usr/bin/env python3
 
 from . import config
+from . import parse_use
 
 from . import date_use
 from . import latex_use
 from . import log_test_use
 from . import os_use
 from . import python_use
-from . import regex_use
 from . import string_use
 from . import url_use
