@@ -3,4 +3,6 @@
 from . import ascii
 from . import date_name
 from . import frame
+from . import group
 from . import latex
+from . import pattern
