@@ -11,10 +11,11 @@ This script gives some useful functions in relation with the powerful LaTeX
 langage for typing scientific documents.
 """
 
-import os
-import subprocess
+from os.path import normpath, join
+from subprocess import check_call, check_output
 
-from mistool import config, os_use
+from mistool import os_use
+from mistool.config import latex
 
 
 # ------------------------- #
@@ -67,8 +68,8 @@ This method simply eases the raising of some specific errors.
 # -- FORMATTING -- #
 # ---------------- #
 
-CHAR_TO_ESCAPE   = config.latex.CHAR_TO_ESCAPE
-CHAR_TO_LATEXIFY = config.latex.CHAR_TO_LATEXIFY
+CHAR_TO_ESCAPE   = latex.CHAR_TO_ESCAPE
+CHAR_TO_LATEXIFY = latex.CHAR_TO_LATEXIFY
 
 def escape(
     text,
@@ -179,11 +180,11 @@ This class uses the following variables.
 # Source :
 #    * http://docs.python.org/py3k/library/subprocess.html
     SUBPROCESS_METHOD = {
-# ``subprocess.check_call`` prints informations given during the compilation.
-        True : subprocess.check_call ,
-# ``subprocess.check_output`` does not print informations given during the
+# ``check_call`` prints informations given during the compilation.
+        True : check_call ,
+# ``check_output`` does not print informations given during the
 # compilation. Indeed it returns all this stuff in one string.
-        False: subprocess.check_output
+        False: check_output
     }
 
     def __init__(
@@ -281,8 +282,8 @@ This method calls LaTeX so as to build the PDF output.
 # -- CLEANING -- #
 # -------------- #
 
-CLASSIFIED_TEMP_EXT = config.latex.CLASSIFIED_TEMP_EXT
-ALL_EXT_TO_CLEAN    = config.latex.ALL_EXT_TO_CLEAN
+CLASSIFIED_TEMP_EXT = latex.CLASSIFIED_TEMP_EXT
+ALL_EXT_TO_CLEAN    = latex.ALL_EXT_TO_CLEAN
 
 def clean(
     main,
@@ -421,22 +422,22 @@ LaTeX packages.
     if osName == None:
         osName = os_use.system()
 
-# "subprocess.check_output" is a byte string, so we have to use the method
+# "check_output" is a byte string, so we have to use the method
 # "decode" so as to obtain an "utf-8" string.
     try:
         if osName == "windows":
-            localDir = subprocess.check_output(
+            localDir = check_output(
                 args = ['kpsexpand',"'$TEXMFLOCAL'"]
             ).decode('utf8')
 
-            return os.path.normpath(localDir.strip())
+            return normpath(localDir.strip())
 
         elif osName in ["linux", "mac"]:
-            localDir = subprocess.check_output(
+            localDir = check_output(
                 args = ['kpsewhich','--var-value=TEXMFLOCAL']
             ).decode('utf8')
 
-            return os.path.normpath(localDir.strip())
+            return normpath(localDir.strip())
 
     except:
         ...
@@ -489,7 +490,7 @@ The key ``'localDir'`` contains the path to use to install special packages.
 # Linux and Mac
     elif osName in ["linux", "mac"]:
 # Is LaTeX installed ?
-        if subprocess.check_output(args = ['which', 'pdftex']).strip():
+        if check_output(args = ['which', 'pdftex']).strip():
             latexFound = True
             latexName = 'texlive'
             localDir = __localDirOfTexLive(osName)
@@ -521,7 +522,7 @@ Small description
 
 This function tests if the script has been launched by the "Super User".
     """
-    path = os.path.join(
+    path = join(
         localLatexDir,
         '-p-y-t-o-o-l-t-e-s-t-.t-x-t-x-t'
     )
@@ -572,7 +573,7 @@ importation of the module ``latexUse``.
         )
 
 # Adding the directory to the ones analysed by MiKTex.
-    subprocess.check_output(
+    check_output(
         args = [
             'initexmf',
             '--admin',
@@ -582,7 +583,7 @@ importation of the module ``latexUse``.
         ]
     )
 
-    subprocess.check_output(
+    check_output(
         args = [
             'initexmf',
             '--update-fndb',
@@ -617,11 +618,11 @@ returned by the function ``about``.
 
 # TeX Live
     if aboutLatex['latexName'] == 'texlive':
-        subprocess.check_call(args = ['mktexlsr'])
+        check_call(args = ['mktexlsr'])
 
 # MiKTex
     elif aboutLatex['latexName'] == 'miktex':
-        subprocess.check_call(args = ['initexmf', '--update-fndb', '--verbose'])
+        check_call(args = ['initexmf', '--update-fndb', '--verbose'])
 
 # Unkonwn !!!
     else:
@@ -682,7 +683,7 @@ This function uses the following variables.
 
         raise LaTeXUseError(message)
 
-    localLatexDir = os.sep.join([
+    localLatexDir = os_use.SEP.join([
         localLatexDir,
         'tex',
         'latex',
