@@ -14,7 +14,7 @@ to have informations about the system.
 import os
 import shutil
 import platform
-import subprocess
+from subprocess import check_call
 
 
 # ------------------------- #
@@ -299,18 +299,18 @@ within their associated applications, if this last ones exist.
         if isOneFile:
             os.startfile(path)
         else:
-            subprocess.check_call(args = ['explorer', path])
+            check_call(args = ['explorer', path])
 
 # Mac
     elif osName == "mac":
-        subprocess.check_call(args = ['open', path])
+        check_call(args = ['open', path])
 
 # Linux
 #
 # Source :
 #     * http://forum.ubuntu-fr.org/viewtopic.php?pid=3952590#p3952590
     elif osName == "linux":
-        subprocess.check_call(args = ['xdg-open', path])
+        check_call(args = ['xdg-open', path])
 
 # Unknown method...
     else:
