@@ -58,7 +58,7 @@ python::
     from mistool import parse_use
 
     myGroups = parse_use.group.Groups(
-        groups =  [
+        groups = [
             ("(", ")"),
             ("[", "]")
         ]
@@ -66,34 +66,38 @@ python::
 
 
 We just have to give a list of tuples of the kind ``(opening delimiter, closing
-delimiter)``. The class build the following dictionary that is stored in the
-attribut ``rules``. You can notice some automatic settings. We will see later
-how to set this particular features.
+delimiter)``.
 
-python::
-    {
-        'all': [
-            '(', '[', ']', ')'
-        ],
-        'open': {
-            '(': ')',
-            '[': ']'
-        },
-        'close': {
-            ')': '(',
-            ']': '['
-        },
-        'escape': {
-            '(': False,
-            ')': False,
-            '[': False,
-            ']': False
-        },
-        'exclude': {},
-        'ignore': {},
-        'untoken': [],
-        'verbatim': []
-    }
+
+info::
+    The class build the following dictionary that is stored in the attribut
+    ``rules``. You can notice some automatic settings. We will see later how to
+    set this particular features.
+
+    python::
+        {
+            'all': [
+                '(', '[', ']', ')'
+            ],
+            'open': {
+                '(': ')',
+                '[': ']'
+            },
+            'close': {
+                ')': '(',
+                ']': '['
+            },
+            'escape': {
+                '(': False,
+                ')': False,
+                '[': False,
+                ']': False
+            },
+            'exclude': {},
+            'ignore': {},
+            'untoken': [],
+            'verbatim': []
+        }
 
 
 -------------------------
@@ -145,11 +149,9 @@ python::
     )
 
 
-Let's suppose know that we also have groups ``( ... )`` that can be escaped. In
-that case, we have to use a code like the one above where instead of using the
-`2`-tuple ``("(", ")")``, we use the `3`-tuple `` ("(", ")", False)`` where the
-additional third boolean value indicate to not escape the delimiters ``(`` and
-``)``.
+Let's suppose know that we also have groups ``( ... )`` that can't be escaped.
+In that case, we just have to use a code like the one above because by default,
+all the groups can not be escaped.
 
 python::
     from mistool import parse_use
@@ -163,10 +165,6 @@ python::
     )
 
 
-info::
-    By default, all the groups can not be escaped.
-
-
 -----------------------------
 Ignoring groups inside others
 -----------------------------
@@ -216,11 +214,11 @@ python::
 
 info::
     You can ask to ignore for example parenthesis inside parenthesis so as to
-    only allow only one level of parenthesis.
+    only have one level of parenthesis.
 
 
 You can easily define more complex rules. Suppose for example that we want to
-ignore parenthesis, hooks and quotes, in any other kind of groups. This can be
+ignore parenthesis, hooks and quotes in any other kind of groups. This can be
 done using dictionary comprehension like in the code above.
 
 python::
@@ -238,16 +236,13 @@ python::
     )
 
 
-The following section gives a mor efficient way to do that.
-
-
 ----------------------
 Verbatim is our friend
 ----------------------
 
-In most langage, ``"..."`` indicates strings where no character have a special
-meaning. Rather than indicating that all the groups must be ignored inside the
-group ``"..."``, it suffises to do as in the following example.
+In most programming langage, ``"..."`` indicates strings where no character have
+a special meaning. Rather than indicating that all the groups must be ignored
+inside the group ``"..."``, it suffises to do as in the following example.
 
 python::
     from mistool import parse_use
@@ -281,9 +276,9 @@ python::
     )
 
 
-----------------------
-Groups to not tokenize
-----------------------
+-------------------------------------
+Groups with a content to not tokenize
+-------------------------------------
 
 The class ``Tokens`` allows to tokenize a text following some simple rules. In
 some circumstances, it is needed to not tokenize some groups. You can indicate
@@ -620,13 +615,14 @@ See the documentation of ``Groups`` so as to learn how to define groups. That's
 a necesserary-to-know documentation.
 
 
-----------------------------------------
-Short overview trough one simple example
-----------------------------------------
+----------------
+A short overview
+----------------
 
 Let's consider the text ``"A(B)C[D(E)F]"`` where there are well balanced groups
 using parenthesis and hooks. The class ``FindGroups`` allows to have easily the
-following ascii tree representing the groups of braces.
+following ascii tree representing the groups. We'll use this ascii tree a lot in
+the coming sections.
 
 terminal::
     + A
@@ -647,7 +643,7 @@ python::
     from mistool import parse_use
 
     myGroups = parse_use.group.Groups(
-        groups =[ ("(", ")"), ("[", "]") ]
+        groups = [ ("(", ")"), ("[", "]") ]
     )
 
     myAnalyze = parse_use.FindGroups(
@@ -662,15 +658,15 @@ info::
     The ascii representation is stored in the attribut ``ascii``.
 
 
-There is an efficient way to walk in the tree. The recursive function ``walkin``
-above shows how to do that kind of thing. In this example, we build by hand
-an ascii tree representing the groups found.
+Let see now how to walk efficiently in the tree. The function ``walkin`` above
+shows how to do that kind of thing. In this example, we build by hand another
+ascii tree representing the groups found.
 
 python::
     from mistool import parse_use
 
     myGroups = parse_use.group.Groups(
-        groups =[ ("(", ")"), ("[", "]") ]
+        groups = [ ("(", ")"), ("[", "]") ]
     )
 
     myAnalyze = parse_use.FindGroups(
@@ -712,7 +708,7 @@ terminal::
 
 Indeed, the class ``FindGroups`` always build first a list view which is stored
 in the attribut ``listView``. For example, by changing ``myAnalyze.ascii``
-to ``myAnalyze.listView`` in the first python code, we obtain the following
+to ``myAnalyze.listView`` in the first Python code, we obtain the following
 output.
 
 terminal::
@@ -744,43 +740,6 @@ In this list, each tuple uses the specification ``(kind, text, depth)``.
     group and so on...
 
 
--------------------------
-Defining one single group
--------------------------
-
-In this well braced expression ``A(B)C(D(E)F)G``, we want only to look for one
-kind of groups so as to obtain the following tree.
-
-terminal::
-    + A
-    + ( ... )
-        + B
-    + C
-    + ( ... )
-        + D
-        + ( ... )
-            + E
-        + F
-    + G
-
-
-This can be obtained using the following code.
-
-python::
-    from mistool import parse_use
-
-    myGroups = parse_use.group.Groups(
-        groups = ("(", ")")
-    )
-
-    myAnalyze = parse_use.FindGroups(
-        text   = "A(B)C(D(E)F)G",
-        groups = myGroups
-    )
-
-    print(myAnalyze)
-
-
 ------------------------------
 Excluding groups inside others
 ------------------------------
@@ -804,6 +763,7 @@ python::
 
     print(myAnalyze)
 
+
 This code will raise the following error message where the symbol ``^`` indicates
 where the problem has been detected.
 
@@ -817,7 +777,7 @@ terminal::
 Analyse several texts
 ---------------------
 
-You can change the attribut ``text``  each time you want like in the following
+You can change the attribut ``text`` each time you want like in the following
 code.
 
 python::
