@@ -10,8 +10,9 @@ Mail      : projetmbc@gmail.com
 This script proposes some useful functions to manipulate urls.
 """
 
-import urllib.parse
-import urllib.request
+from urllib.parse import quote
+from urllib.request import urlopen
+from urllib.error import URLError
 
 
 # ------------------------- #
@@ -48,7 +49,7 @@ This function escapes no ASCII characters in urls. For example,
 The function uses the global string ``CHAR_TO_KEEP`` which contains the
 characters that must not be escaped : ``"/:#&?="``.
     """
-    return urllib.parse.quote(
+    return quote(
         string = url,
         safe   = CHAR_TO_KEEP
     )
@@ -77,17 +78,17 @@ for the whole duration of the test. By default, this variable is equal to
     """
     try:
         if timeout == -1:
-            urllib.request.urlopen(url)
+            urlopen(url)
 
         else:
-            urllib.request.urlopen(
+            urlopen(
                 url = url,
                 timeout = timeout
             )
 
         return True
 
-    except urllib.error.URLError as e:
+    except URLError as e:
         ...
 
     return False
